@@ -30,7 +30,7 @@ in games (who'll be the wolf?)
     Bourre, bourre et ratatam
     Am, stram, gram.
 
-=head2 DUTCH
+=head2 Dutch
 
     Iene, miene, mutte,
     tien pond grutten,
@@ -38,10 +38,19 @@ in games (who'll be the wolf?)
     Iene, miene, mutte,
     is de baas.
 
+=head2 German
+
+    Eene, Meene, Muh, und raus bist du
+    Eene, Meene, Maus, und du bist raus
+    Eene, Meene, Meck, und du bist weg
+    Weg bist du noch lange nicht,
+    sag mir erst wie alt du bist.
+
 =head1 CONTRIBUTORS
 
 Xavier Caron proposed the idea in French, and Paul-Christophe Varoutas
 provided the English version. Abigail provided the Dutch version.
+Yanick and Anja Champoux provided the German theme.
 
 Introduced in version 0.30, published on July 11, 2005.
 
@@ -49,9 +58,11 @@ Patched a typo in version 0.39, published on September 12, 2005.
 
 Updated with the Dutch theme in version 0.47, published on November 7, 2005.
 
+Updated with the German theme in version 0.68, published on April 3, 2006.
+
 =head1 SEE ALSO
 
-L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
+L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.
 
 =cut
 
@@ -70,4 +81,8 @@ bourre ratatam
 iene miene mutte
 tien pond grutten
 kaas is de baas
-
+# names de
+eene meene muh und raus bist du 
+maus meck weg 
+noch lange nicht 
+sag mir erst wie alt
