@@ -1,6 +1,7 @@
 package Acme::MetaSyntactic::quantum;
+use strict;
 use Acme::MetaSyntactic::List;
-@ISA = qw(Acme::MetaSyntactic::List);
+our @ISA = qw(Acme::MetaSyntactic::List);
 __PACKAGE__->init();
 1;
 
